# Generated by roxygen2: do not edit by hand

S3method(bag_samples,default)
S3method(bag_samples,pprf)
S3method(fitted,ppmodel)
S3method(formula,ppmodel)
S3method(nobs,ppmodel)
S3method(oob_error,default)
S3method(oob_error,pprf)
S3method(oob_predictions,default)
S3method(oob_predictions,pprf_classification)
S3method(oob_predictions,pprf_regression)
S3method(oob_samples,default)
S3method(oob_samples,pprf)
S3method(permuted_importance,default)
S3method(permuted_importance,pprf)
S3method(plot,pprf)
S3method(plot,pptr)
S3method(predict,pprf_classification)
S3method(predict,pprf_regression)
S3method(predict,pptr_classification)
S3method(predict,pptr_regression)
S3method(print,pprf)
S3method(print,pptr)
S3method(print_node,pptr_classification)
S3method(print_node,pptr_regression)
S3method(projection_importance,default)
S3method(projection_importance,ppmodel)
S3method(residuals,ppmodel)
S3method(save_json,ppmodel)
S3method(summary,ppmodel)
S3method(summary,pprf)
S3method(summary,pprf_classification)
S3method(summary,pprf_regression)
S3method(summary,pptr)
S3method(summary,pptr_classification)
S3method(summary,pptr_regression)
S3method(update,pp_rand_forest)
S3method(update,pp_tree)
S3method(weighted_importance,default)
S3method(weighted_importance,pprf)
export(bag_samples)
export(binarize_disabled)
export(binarize_largest_gap)
export(cutpoint_mean_of_means)
export(grouping_by_cutpoint)
export(grouping_by_label)
export(leaf_majority_vote)
export(leaf_mean_response)
export(load_json)
export(oob_error)
export(oob_predictions)
export(oob_samples)
export(permuted_importance)
export(pp_pda)
export(pp_rand_forest)
export(pp_tree)
export(pprf)
export(pptr)
export(projection_importance)
export(save_json)
export(stop_any)
export(stop_max_depth)
export(stop_min_size)
export(stop_min_variance)
export(stop_pure_node)
export(vars_all)
export(vars_uniform)
export(weighted_importance)
importFrom(Rcpp,evalCpp)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,nobs)
importFrom(stats,predict)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,terms)
importFrom(stats,update)
useDynLib(ppforest2)
