% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/parsnip.R
\name{update.pp_tree}
\alias{update.pp_tree}
\title{Update a \code{pp_tree} model specification.}
\usage{
\method{update}{pp_tree}(object, parameters = NULL, penalty = NULL, fresh = FALSE, ...)
}
\arguments{
\item{object}{A \code{pp_tree} model specification.}

\item{parameters}{A named list of parameters to update (alternative to passing them as args).}

\item{penalty}{A new value for the regularisation parameter.}

\item{fresh}{If \code{TRUE}, drop any previously-set arg whose new value is not provided.}

\item{...}{Engine-specific arguments to update.}
}
\value{
An updated \code{pp_tree} model specification.
}
\description{
Companion to \code{\link{update.pp_rand_forest}} — exists for the same
reason (\code{tune::tune_grid()} relies on \code{update()} to finalise the
spec at each grid point).
}
