% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grouping-strategy.R
\name{grouping_by_cutpoint}
\alias{grouping_by_cutpoint}
\title{Cutpoint-based grouping strategy (regression).}
\usage{
grouping_by_cutpoint()
}
\value{
A \code{grouping_strategy} object.
}
\description{
Creates a grouping strategy for regression trees: observations are split by
the cutpoint in projected space, then each child's observations are sorted
by the continuous response and median-split into 2 new groups for the next
projection-pursuit step. This is the default grouping strategy for regression.
}
\examples{
grouping_by_cutpoint()

}
\seealso{
\code{\link{pptr}}, \code{\link{pprf}}, \code{\link{grouping_by_label}}
}
