% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ppmodel.R
\name{bag_samples}
\alias{bag_samples}
\title{In-bag row indices per tree.}
\usage{
bag_samples(model)
}
\arguments{
\item{model}{A \code{pprf} forest model.}
}
\value{
A list of integer vectors, one per tree.
}
\description{
Returns a list where element `i` is the integer vector of row indices
(1-based, with replacement) drawn into the bootstrap sample of tree `i`.
}
\seealso{
\code{\link{oob_samples}}
}
