% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pptr.R
\name{predict.pptr_regression}
\alias{predict.pptr_regression}
\title{Predicts numeric responses from a pptr model (regression mode).}
\usage{
\method{predict}{pptr_regression}(object, new_data = NULL, type = NULL, ...)
}
\arguments{
\item{object}{A \code{pptr_regression} model.}

\item{new_data}{A data frame or matrix of new observations.}

\item{type}{Must be \code{"response"} (default).}

\item{...}{Backward-compat positional `new_data`.}
}
\value{
A numeric vector.
}
\description{
Predicts numeric responses from a pptr model (regression mode).
}
\seealso{
\code{\link{pptr}}, \code{\link{predict.pptr_classification}}
}
