% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pprf.R
\name{predict.pprf_regression}
\alias{predict.pprf_regression}
\title{Predicts numeric responses from a pprf model (regression mode).}
\usage{
\method{predict}{pprf_regression}(object, new_data = NULL, type = NULL, ...)
}
\arguments{
\item{object}{A \code{pprf_regression} model.}

\item{new_data}{A data frame or matrix of new observations.}

\item{type}{Must be \code{"response"} (default).}

\item{...}{For backward compatibility, the first positional argument is treated as \code{new_data} when \code{new_data} is \code{NULL}.}
}
\value{
A numeric vector of mean predictions across the forest's trees.
}
\description{
Predicts numeric responses from a pprf model (regression mode).
}
\seealso{
\code{\link{pprf}}, \code{\link{predict.pprf_classification}}
}
